Module errors

Module errors 

Structs

Error
The error type returned from star_frame traits and functions.
ErrorInner
The main body of the error struct, which is boxed to form Error.
ErrorSource
Where the error occurred

Enums

ErrorCode
Error codes for errors emitted by star_frame
ErrorKind
The kind of error. Either a ProgramError or a custom error implementing StarFrameError.

Traits

ErrorInfo
Adds additional context to an error, while automatically converting to the Error type.
StarFrameError
Represents something that can be used as a error.

Attribute Macros

star_frame_error
Derives the StarFrameError and ErrorsToIdl traits on an enum.