Structs
- Error
- The error type returned from
star_frametraits and functions. - Error
Inner - The main body of the error struct, which is boxed to form
Error. - Error
Source - Where the error occurred
Enums
- Error
Code - Error codes for errors emitted by
star_frame - Error
Kind - The kind of error. Either a
ProgramErroror a custom error implementingStarFrameError.
Traits
- Error
Info - Adds additional context to an error, while automatically converting to the
Errortype. - Star
Frame Error - Represents something that can be used as a error.
Attribute Macros
- star_
frame_ error - Derives the
StarFrameErrorandErrorsToIdltraits on an enum.